@@ -1,6 +1,6 @@
 ### SHELL> mpiexec -np 2 Rscript --vanilla [...].r
 
-library(pbdMPI, quietly = TRUE)
+suppressMessages(library(pbdMPI, quietly = TRUE))
 init()
 .comm.size <- comm.size()
 .comm.rank <- comm.rank()
@@ -40,4 +40,3 @@ comm.print(y, rank.print = 1)
 waitall(as.integer(comm.size()))
 
 finalize()
-
